summaryrefslogtreecommitdiffstats
path: root/kicker/kicker
diff options
context:
space:
mode:
Diffstat (limited to 'kicker/kicker')
-rw-r--r--kicker/kicker/buttons/browserbutton.cpp2
-rw-r--r--kicker/kicker/buttons/desktopbutton.cpp2
-rw-r--r--kicker/kicker/core/applethandle.cpp16
-rw-r--r--kicker/kicker/core/applethandle.h12
-rw-r--r--kicker/kicker/core/container_applet.cpp8
-rw-r--r--kicker/kicker/core/container_base.cpp2
-rw-r--r--kicker/kicker/core/container_base.h2
-rw-r--r--kicker/kicker/core/container_extension.cpp24
-rw-r--r--kicker/kicker/core/container_extension.h4
-rw-r--r--kicker/kicker/core/containerarea.cpp12
-rw-r--r--kicker/kicker/core/containerarea.h2
-rw-r--r--kicker/kicker/core/containerarealayout.cpp8
-rw-r--r--kicker/kicker/core/containerarealayout.h4
-rw-r--r--kicker/kicker/core/extensionmanager.cpp2
-rw-r--r--kicker/kicker/core/kmenubase.ui16
-rw-r--r--kicker/kicker/core/menumanager.cpp8
-rw-r--r--kicker/kicker/core/panelextension.cpp4
-rw-r--r--kicker/kicker/core/panelextension.h2
-rw-r--r--kicker/kicker/plugins/beaglesearch.cpp2
-rw-r--r--kicker/kicker/ui/addapplet.cpp4
-rw-r--r--kicker/kicker/ui/addappletvisualfeedback.cpp6
-rw-r--r--kicker/kicker/ui/appletitem.ui6
-rw-r--r--kicker/kicker/ui/appletview.ui4
-rw-r--r--kicker/kicker/ui/browser_mnu.cpp2
-rw-r--r--kicker/kicker/ui/exe_dlg.cpp4
-rw-r--r--kicker/kicker/ui/flipscrollview.cpp2
-rw-r--r--kicker/kicker/ui/hidebutton.cpp8
-rw-r--r--kicker/kicker/ui/itemview.cpp18
-rw-r--r--kicker/kicker/ui/itemview.h2
-rw-r--r--kicker/kicker/ui/k_mnu.cpp16
-rw-r--r--kicker/kicker/ui/k_mnu.h2
-rw-r--r--kicker/kicker/ui/k_mnu_stub.cpp6
-rw-r--r--kicker/kicker/ui/k_mnu_stub.h2
-rw-r--r--kicker/kicker/ui/k_new_mnu.cpp90
-rw-r--r--kicker/kicker/ui/k_new_mnu.h6
-rw-r--r--kicker/kicker/ui/kickoff_bar.cpp20
-rw-r--r--kicker/kicker/ui/kickoff_bar.h2
-rw-r--r--kicker/kicker/ui/kmenuitembase.ui6
-rw-r--r--kicker/kicker/ui/nonKDEButtonSettings.ui8
-rw-r--r--kicker/kicker/ui/popupmenutitle.h4
-rw-r--r--kicker/kicker/ui/service_mnu.cpp4
41 files changed, 177 insertions, 177 deletions
diff --git a/kicker/kicker/buttons/browserbutton.cpp b/kicker/kicker/buttons/browserbutton.cpp
index 4a8c9a7af..2e2cb5a2d 100644
--- a/kicker/kicker/buttons/browserbutton.cpp
+++ b/kicker/kicker/buttons/browserbutton.cpp
@@ -103,7 +103,7 @@ void BrowserButton::dropEvent( TQDropEvent *ev )
{
KURL path ( topMenu->path() );
_menuTimer->stop();
- KFileItem item( path, TQString::tqfromLatin1( "inode/directory" ), KFileItem::Unknown );
+ KFileItem item( path, TQString::fromLatin1( "inode/directory" ), KFileItem::Unknown );
KonqOperations::doDrop( &item, path, ev, this );
PanelButton::dropEvent(ev);
}
diff --git a/kicker/kicker/buttons/desktopbutton.cpp b/kicker/kicker/buttons/desktopbutton.cpp
index 71bcaa2e5..9f23741e5 100644
--- a/kicker/kicker/buttons/desktopbutton.cpp
+++ b/kicker/kicker/buttons/desktopbutton.cpp
@@ -77,7 +77,7 @@ void DesktopButton::dragEnterEvent( TQDragEnterEvent *ev )
void DesktopButton::dropEvent( TQDropEvent *ev )
{
KURL dPath ( KGlobalSettings::desktopPath() );
- KFileItem item( dPath, TQString::tqfromLatin1( "inode/directory" ), KFileItem::Unknown );
+ KFileItem item( dPath, TQString::fromLatin1( "inode/directory" ), KFileItem::Unknown );
KonqOperations::doDrop( &item, dPath, ev, this );
PanelButton::dropEvent(ev);
}
diff --git a/kicker/kicker/core/applethandle.cpp b/kicker/kicker/core/applethandle.cpp
index 382779648..6b03269eb 100644
--- a/kicker/kicker/core/applethandle.cpp
+++ b/kicker/kicker/core/applethandle.cpp
@@ -75,14 +75,14 @@ AppletHandle::AppletHandle(AppletContainer* parent)
int AppletHandle::heightForWidth( int /* w */ ) const
{
- int size = tqstyle().tqpixelMetric(TQStyle::PM_DockWindowHandleExtent, this);
+ int size = tqstyle().pixelMetric(TQStyle::PM_DockWindowHandleExtent, this);
return size;
}
int AppletHandle::widthForHeight( int /* h */ ) const
{
- int size = tqstyle().tqpixelMetric(TQStyle::PM_DockWindowHandleExtent, this);
+ int size = tqstyle().pixelMetric(TQStyle::PM_DockWindowHandleExtent, this);
return size;
}
@@ -282,7 +282,7 @@ void AppletHandle::checkHandleHover()
bool AppletHandle::onMenuButton(const TQPoint& point) const
{
- return m_menuButton && (tqchildAt(mapFromGlobal(point)) == m_menuButton);
+ return m_menuButton && (childAt(mapFromGlobal(point)) == m_menuButton);
}
void AppletHandle::toggleMenuButtonOff()
@@ -308,9 +308,9 @@ AppletHandleDrag::AppletHandleDrag(AppletHandle* parent)
setBackgroundOrigin( AncestorOrigin );
}
-TQSize AppletHandleDrag::tqminimumSizeHint() const
+TQSize AppletHandleDrag::minimumSizeHint() const
{
- int wh = tqstyle().tqpixelMetric(TQStyle::PM_DockWindowHandleExtent, this);
+ int wh = tqstyle().pixelMetric(TQStyle::PM_DockWindowHandleExtent, this);
if (m_parent->orientation() == Qt::Horizontal)
{
@@ -368,7 +368,7 @@ void AppletHandleDrag::paintEvent(TQPaintEvent *)
TQRect r = rect();
tqstyle().tqdrawPrimitive(TQStyle::PE_DockWindowHandle, &p, r,
- tqcolorGroup(), flags);
+ colorGroup(), flags);
}
else
{
@@ -382,9 +382,9 @@ AppletHandleButton::AppletHandleButton(AppletHandle *parent)
{
}
-TQSize AppletHandleButton::tqminimumSizeHint() const
+TQSize AppletHandleButton::minimumSizeHint() const
{
- int height = tqstyle().tqpixelMetric(TQStyle::PM_DockWindowHandleExtent, this);
+ int height = tqstyle().pixelMetric(TQStyle::PM_DockWindowHandleExtent, this);
int width = height;
if (m_parent->orientation() == Qt::Horizontal)
diff --git a/kicker/kicker/core/applethandle.h b/kicker/kicker/core/applethandle.h
index a49319dc6..34e8e3576 100644
--- a/kicker/kicker/core/applethandle.h
+++ b/kicker/kicker/core/applethandle.h
@@ -92,9 +92,9 @@ class AppletHandleDrag : public TQWidget
public:
AppletHandleDrag(AppletHandle* parent);
- TQSize tqminimumSizeHint() const;
- TQSize tqminimumSize() const { return tqminimumSizeHint(); }
- TQSize tqsizeHint() const { return tqminimumSize(); }
+ TQSize minimumSizeHint() const;
+ TQSize minimumSize() const { return minimumSizeHint(); }
+ TQSize sizeHint() const { return minimumSize(); }
TQSizePolicy sizePolicy() const;
protected:
@@ -113,9 +113,9 @@ class AppletHandleButton : public SimpleArrowButton
public:
AppletHandleButton(AppletHandle *parent);
- TQSize tqminimumSizeHint() const;
- TQSize tqminimumSize() const { return tqminimumSizeHint(); }
- TQSize tqsizeHint() const { return tqminimumSize(); }
+ TQSize minimumSizeHint() const;
+ TQSize minimumSize() const { return minimumSizeHint(); }
+ TQSize sizeHint() const { return minimumSize(); }
TQSizePolicy sizePolicy() const;
private:
diff --git a/kicker/kicker/core/container_applet.cpp b/kicker/kicker/core/container_applet.cpp
index a6cfc11ab..47a07a5f5 100644
--- a/kicker/kicker/core/container_applet.cpp
+++ b/kicker/kicker/core/container_applet.cpp
@@ -117,7 +117,7 @@ AppletContainer::AppletContainer(const AppletInfo& info,
_valid = true;
_applet->setPosition((KPanelApplet::Position)KickerLib::directionToPosition(popupDirection()));
- _applet->tqsetAlignment((KPanelApplet::Alignment)tqalignment());
+ _applet->setAlignment((KPanelApplet::Alignment)tqalignment());
_actions = _applet->actions();
_type = _applet->type();
@@ -275,14 +275,14 @@ void AppletContainer::slotRemoved(KConfig* config)
void AppletContainer::activateWindow()
{
- KWin::forceActiveWindow(tqtopLevelWidget()->winId());
+ KWin::forceActiveWindow(topLevelWidget()->winId());
}
void AppletContainer::focusRequested(bool focus)
{
if (focus)
{
- KWin::forceActiveWindow(tqtopLevelWidget()->winId());
+ KWin::forceActiveWindow(topLevelWidget()->winId());
}
emit maintainFocus(focus);
@@ -361,7 +361,7 @@ void AppletContainer::alignmentChange(KPanelExtension::Alignment a)
return;
}
- _applet->tqsetAlignment( (KPanelApplet::Alignment)a );
+ _applet->setAlignment( (KPanelApplet::Alignment)a );
}
int AppletContainer::widthForHeight(int h) const
diff --git a/kicker/kicker/core/container_base.cpp b/kicker/kicker/core/container_base.cpp
index 2607e3608..0b1ff30f7 100644
--- a/kicker/kicker/core/container_base.cpp
+++ b/kicker/kicker/core/container_base.cpp
@@ -110,7 +110,7 @@ void BaseContainer::slotRemoved(KConfig* config)
config->sync();
}
-void BaseContainer::tqsetAlignment(KPanelExtension::Alignment a)
+void BaseContainer::setAlignment(KPanelExtension::Alignment a)
{
if (_tqalignment == a)
{
diff --git a/kicker/kicker/core/container_base.h b/kicker/kicker/core/container_base.h
index f9c449b1f..0c4a79539 100644
--- a/kicker/kicker/core/container_base.h
+++ b/kicker/kicker/core/container_base.h
@@ -97,7 +97,7 @@ public slots:
virtual void setPopupDirection(KPanelApplet::Direction d) { _dir = d; }
virtual void setOrientation(KPanelExtension::Orientation o) { _orient = o; }
- void tqsetAlignment(KPanelExtension::Alignment a);
+ void setAlignment(KPanelExtension::Alignment a);
signals:
void removeme(BaseContainer*);
diff --git a/kicker/kicker/core/container_extension.h b/kicker/kicker/core/container_extension.h
index 3c7894db6..c6347ba08 100644
--- a/kicker/kicker/core/container_extension.h
+++ b/kicker/kicker/core/container_extension.h
@@ -66,7 +66,7 @@ public:
TQWidget *parent = 0);
virtual ~ExtensionContainer();
- virtual TQSize tqsizeHint(KPanelExtension::Position, const TQSize &maxSize) const;
+ virtual TQSize sizeHint(KPanelExtension::Position, const TQSize &maxSize) const;
const AppletInfo& info() const { return _info; }
@@ -101,7 +101,7 @@ public:
bool reserveStrut() const;
KPanelExtension::Alignment tqalignment() const;
- void tqsetAlignment(KPanelExtension::Alignment a) { arrange( position(), a, xineramaScreen() ); }
+ void setAlignment(KPanelExtension::Alignment a) { arrange( position(), a, xineramaScreen() ); }
TQRect currentGeometry() const;
TQRect initialGeometry(KPanelExtension::Position p, KPanelExtension::Alignment a,
diff --git a/kicker/kicker/core/containerarea.cpp b/kicker/kicker/core/containerarea.cpp
index 00d781b98..20f6720d7 100644
--- a/kicker/kicker/core/containerarea.cpp
+++ b/kicker/kicker/core/containerarea.cpp
@@ -1430,7 +1430,7 @@ void ContainerArea::setBackground()
if (KickerSettings::transparent() &&
(KickerSettings::menubarPanelTransparent() ||
- !ExtensionManager::the()->isMenuBar(tqtopLevelWidget())))
+ !ExtensionManager::the()->isMenuBar(topLevelWidget())))
{
if (!_rootPixmap)
{
@@ -1639,7 +1639,7 @@ void ContainerArea::moveDragIndicator(int pos)
void ContainerArea::updateBackground( const TQPixmap& pm )
{
- TQBrush bgBrush(tqcolorGroup().background(), pm);
+ TQBrush bgBrush(colorGroup().background(), pm);
TQPalette pal = kapp->palette();
pal.setBrush(TQColorGroup::Background, bgBrush);
setPalette(pal);
@@ -1728,13 +1728,13 @@ void ContainerArea::setPosition(KPanelExtension::Position p)
//tqrepaint();
}
-void ContainerArea::tqsetAlignment(KPanelExtension::Alignment a)
+void ContainerArea::setAlignment(KPanelExtension::Alignment a)
{
for (BaseContainer::ConstIterator it = m_containers.begin();
it != m_containers.end();
++it)
{
- (*it)->tqsetAlignment(a);
+ (*it)->setAlignment(a);
}
}
@@ -1958,8 +1958,8 @@ void DragIndicator::paintEvent(TQPaintEvent*)
{
TQPainter painter(this);
TQRect rect(0, 0, width(), height());
- tqstyle().tqdrawPrimitive( TQStyle::PE_FocusRect, &painter, rect, tqcolorGroup(),
- TQStyle::Style_Default, tqcolorGroup().base() );
+ tqstyle().tqdrawPrimitive( TQStyle::PE_FocusRect, &painter, rect, colorGroup(),
+ TQStyle::Style_Default, colorGroup().base() );
}
void DragIndicator::mousePressEvent(TQMouseEvent*)
diff --git a/kicker/kicker/core/containerarea.h b/kicker/kicker/core/containerarea.h
index 3dc494798..8b473124e 100644
--- a/kicker/kicker/core/containerarea.h
+++ b/kicker/kicker/core/containerarea.h
@@ -101,7 +101,7 @@ public slots:
void removeContainers(BaseContainer::List containers);
void takeContainer(BaseContainer* a);
void setPosition(KPanelExtension::Position p);
- void tqsetAlignment(KPanelExtension::Alignment a);
+ void setAlignment(KPanelExtension::Alignment a);
void slotSaveContainerConfig();
void tqrepaint();
void showAddAppletDialog();
diff --git a/kicker/kicker/core/containerarealayout.cpp b/kicker/kicker/core/containerarealayout.cpp
index e33a78518..dc325597b 100644
--- a/kicker/kicker/core/containerarealayout.cpp
+++ b/kicker/kicker/core/containerarealayout.cpp
@@ -81,7 +81,7 @@ int ContainerAreaLayoutItem::heightForWidth(int w) const
}
else
{
- return item->tqsizeHint().height();
+ return item->sizeHint().height();
}
}
@@ -94,7 +94,7 @@ int ContainerAreaLayoutItem::widthForHeight(int h) const
}
else
{
- return item->tqsizeHint().width();
+ return item->sizeHint().width();
}
}
@@ -415,7 +415,7 @@ TQWidget* ContainerAreaLayout::widgetAt(int index) const
return m_items[index]->item->widget();
}
-TQSize ContainerAreaLayout::tqsizeHint() const
+TQSize ContainerAreaLayout::sizeHint() const
{
const int size = KickerLib::sizeValue(KPanelExtension::SizeSmall);
@@ -429,7 +429,7 @@ TQSize ContainerAreaLayout::tqsizeHint() const
}
}
-TQSize ContainerAreaLayout::tqminimumSize() const
+TQSize ContainerAreaLayout::minimumSize() const
{
const int size = KickerLib::sizeValue(KPanelExtension::SizeTiny);
diff --git a/kicker/kicker/core/containerarealayout.h b/kicker/kicker/core/containerarealayout.h
index 41a104929..4edeb8be2 100644
--- a/kicker/kicker/core/containerarealayout.h
+++ b/kicker/kicker/core/containerarealayout.h
@@ -83,8 +83,8 @@ class ContainerAreaLayout : public TQLayout
void insertIntoFreeSpace(TQWidget* item, TQPoint insertionPoint);
TQStringList listItems() const;
TQWidget* widgetAt(int index) const;
- TQSize tqsizeHint() const;
- TQSize tqminimumSize() const;
+ TQSize sizeHint() const;
+ TQSize minimumSize() const;
TQLayoutIterator iterator();
void setGeometry(const TQRect& rect);
diff --git a/kicker/kicker/core/extensionmanager.cpp b/kicker/kicker/core/extensionmanager.cpp
index d3ec91e2c..00b0eeae3 100644
--- a/kicker/kicker/core/extensionmanager.cpp
+++ b/kicker/kicker/core/extensionmanager.cpp
@@ -371,7 +371,7 @@ void ExtensionManager::updateMenubar()
KMenuBar tmpmenu;
tmpmenu.insertItem("KDE Rocks!");
m_menubarPanel->setSize(KPanelExtension::SizeCustom,
- tmpmenu.tqsizeHint().height());
+ tmpmenu.sizeHint().height());
m_menubarPanel->writeConfig();
emit desktopIconsAreaChanged(desktopIconsArea(m_menubarPanel->xineramaScreen()),
diff --git a/kicker/kicker/core/kmenubase.ui b/kicker/kicker/core/kmenubase.ui
index 8a86f366d..f76942c94 100644
--- a/kicker/kicker/core/kmenubase.ui
+++ b/kicker/kicker/core/kmenubase.ui
@@ -55,13 +55,13 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>52</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>32767</width>
<height>52</height>
@@ -129,13 +129,13 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>32</width>
<height>32</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>32</width>
<height>32</height>
@@ -165,7 +165,7 @@
<property name="sizeType">
<enum>Preferred</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -222,7 +222,7 @@
<property name="sizeType">
<enum>MinimumExpanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>10</width>
<height>20</height>
@@ -241,7 +241,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>90</width>
<height>24</height>
@@ -270,7 +270,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>14</width>
<height>20</height>
diff --git a/kicker/kicker/core/panelextension.cpp b/kicker/kicker/core/panelextension.cpp
index d11c14c28..73fa0c2b0 100644
--- a/kicker/kicker/core/panelextension.cpp
+++ b/kicker/kicker/core/panelextension.cpp
@@ -100,7 +100,7 @@ void PanelExtension::populateContainerArea()
{
_containerArea->show();
- if (ExtensionManager::the()->isMainPanel(tqtopLevelWidget()))
+ if (ExtensionManager::the()->isMainPanel(topLevelWidget()))
{
setObjId("Panel");
_containerArea->initialize(true);
@@ -139,7 +139,7 @@ void PanelExtension::positionChange(Position p)
_containerArea->setPosition(p);
}
-TQSize PanelExtension::tqsizeHint(Position p, TQSize maxSize) const
+TQSize PanelExtension::sizeHint(Position p, TQSize maxSize) const
{
TQSize size;
diff --git a/kicker/kicker/core/panelextension.h b/kicker/kicker/core/panelextension.h
index 61e6c229c..c7882291f 100644
--- a/kicker/kicker/core/panelextension.h
+++ b/kicker/kicker/core/panelextension.h
@@ -80,7 +80,7 @@ k_dcop:
void configure(); // KDE4: remove, moved to Kikcker
public:
- TQSize tqsizeHint(Position, TQSize maxSize) const;
+ TQSize sizeHint(Position, TQSize maxSize) const;
Position preferedPosition() const { return Bottom; }
bool eventFilter( TQObject *, TQEvent * );
diff --git a/kicker/kicker/plugins/beaglesearch.cpp b/kicker/kicker/plugins/beaglesearch.cpp
index f75f719ab..9f86c8fbd 100644
--- a/kicker/kicker/plugins/beaglesearch.cpp
+++ b/kicker/kicker/plugins/beaglesearch.cpp
@@ -347,7 +347,7 @@ BeagleUtil::timestringToBeagleTimestamp(TQString timestring)
//kdDebug () << "datetime string:" << timestring << endl;
// FIXME: error check timestring format
if (timestring.isNull () || timestring.stripWhiteSpace () == "" || timestring.length() != 8 )
- return beagle_timestamp_new_from_unix_time (TQDateTime::tqcurrentDateTime ().toTime_t ());
+ return beagle_timestamp_new_from_unix_time (TQDateTime::currentDateTime ().toTime_t ());
//TQDateTime dt = TQDateTime::fromString (timestring, Qt::ISODate);
struct tm tm_time;
time_t timet_time;
diff --git a/kicker/kicker/ui/addapplet.cpp b/kicker/kicker/ui/addapplet.cpp
index 163a4ae9d..133df0016 100644
--- a/kicker/kicker/ui/addapplet.cpp
+++ b/kicker/kicker/ui/addapplet.cpp
@@ -291,7 +291,7 @@ void AddAppletDialog::resizeAppletView()
{
m_appletBox->layout()->activate();
w = v->visibleWidth();
- h = m_appletBox->tqlayout()->tqminimumSize().height();
+ h = m_appletBox->tqlayout()->minimumSize().height();
v->resizeContents(w, QMAX(h, v->visibleHeight()));
if (w == m_appletBox->width() && h == m_appletBox->height())
break;
@@ -456,7 +456,7 @@ void AddAppletDialog::addApplet(AppletWidget* applet)
if (appletContainer)
{
ExtensionContainer* ec =
- dynamic_cast<ExtensionContainer*>(m_containerArea->tqtopLevelWidget());
+ dynamic_cast<ExtensionContainer*>(m_containerArea->topLevelWidget());
if (ec)
{
diff --git a/kicker/kicker/ui/addappletvisualfeedback.cpp b/kicker/kicker/ui/addappletvisualfeedback.cpp
index 7f4f90676..294be2463 100644
--- a/kicker/kicker/ui/addappletvisualfeedback.cpp
+++ b/kicker/kicker/ui/addappletvisualfeedback.cpp
@@ -157,7 +157,7 @@ void AddAppletVisualFeedback::displayInternal()
// draw background
TQPainter bufferPainter(&m_pixmap);
bufferPainter.setPen(Qt::black);
- bufferPainter.setBrush(tqcolorGroup().background());
+ bufferPainter.setBrush(colorGroup().background());
bufferPainter.drawRoundRect(0, 0, width, height,
1600 / width, 1600 / height);
@@ -175,14 +175,14 @@ void AddAppletVisualFeedback::displayInternal()
int textY = (height - textRect.height()) / 2;
// draw text shadow
- TQColorGroup cg = tqcolorGroup();
+ TQColorGroup cg = colorGroup();
cg.setColor(TQColorGroup::Text, cg.background().dark(115));
int shadowOffset = TQApplication::reverseLayout() ? -1 : 1;
m_richText->draw(&bufferPainter, 5 + textX + shadowOffset,
textY + 1, TQRect(), cg);
// draw text
- cg = tqcolorGroup();
+ cg = colorGroup();
m_richText->draw(&bufferPainter, 5 + textX, textY, rect(), cg);
}
}
diff --git a/kicker/kicker/ui/appletitem.ui b/kicker/kicker/ui/appletitem.ui
index dc6faab50..7ddb827b4 100644
--- a/kicker/kicker/ui/appletitem.ui
+++ b/kicker/kicker/ui/appletitem.ui
@@ -20,13 +20,13 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>0</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>32767</width>
<height>80</height>
@@ -105,7 +105,7 @@
<property name="name">
<cstring>itemPixmap</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>64</width>
<height>64</height>
diff --git a/kicker/kicker/ui/appletview.ui b/kicker/kicker/ui/appletview.ui
index 4ba0f38e8..f5a32651b 100644
--- a/kicker/kicker/ui/appletview.ui
+++ b/kicker/kicker/ui/appletview.ui
@@ -110,7 +110,7 @@
<verstretch>1</verstretch>
</sizepolicy>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>32767</width>
<height>32767</height>
@@ -141,7 +141,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>284</width>
<height>20</height>
diff --git a/kicker/kicker/ui/browser_mnu.cpp b/kicker/kicker/ui/browser_mnu.cpp
index ee62791e9..4998fc5cf 100644
--- a/kicker/kicker/ui/browser_mnu.cpp
+++ b/kicker/kicker/ui/browser_mnu.cpp
@@ -429,7 +429,7 @@ void PanelBrowserMenu::dragMoveEvent(TQDragMoveEvent *ev)
void PanelBrowserMenu::dropEvent( TQDropEvent *ev )
{
KURL u( path() );
- KFileItem item( u, TQString::tqfromLatin1( "inode/directory" ), KFileItem::Unknown );
+ KFileItem item( u, TQString::fromLatin1( "inode/directory" ), KFileItem::Unknown );
KonqOperations::doDrop( &item, u, ev, this );
KPanelMenu::dropEvent(ev);
// ### TODO: Update list
diff --git a/kicker/kicker/ui/exe_dlg.cpp b/kicker/kicker/ui/exe_dlg.cpp
index d39fb5942..6b1dd15ef 100644
--- a/kicker/kicker/ui/exe_dlg.cpp
+++ b/kicker/kicker/ui/exe_dlg.cpp
@@ -78,8 +78,8 @@ PanelExeDialog::PanelExeDialog(const TQString& title, const TQString& descriptio
this, TQT_SLOT(slotIconChanged(TQString)));
// leave decent space for the commandline
- resize(tqsizeHint().width() > 300 ? tqsizeHint().width() : 300,
- tqsizeHint().height());
+ resize(sizeHint().width() > 300 ? sizeHint().width() : 300,
+ sizeHint().height());
}
void PanelExeDialog::slotOk()
diff --git a/kicker/kicker/ui/flipscrollview.cpp b/kicker/kicker/ui/flipscrollview.cpp
index fb5cfd422..34b3b310f 100644
--- a/kicker/kicker/ui/flipscrollview.cpp
+++ b/kicker/kicker/ui/flipscrollview.cpp
@@ -57,7 +57,7 @@ void BackFrame::drawContents( TQPainter *p )
{
TQColor gray( 230, 230, 230 );
if ( mouse_inside )
- p->fillRect( 3, 3, width() - 6, height() - 6, tqcolorGroup().color( TQColorGroup::Highlight ) );
+ p->fillRect( 3, 3, width() - 6, height() - 6, colorGroup().color( TQColorGroup::Highlight ) );
else
p->fillRect( 3, 3, width() - 6, height() - 6, gray );
p->setPen( gray.dark(110) );
diff --git a/kicker/kicker/ui/hidebutton.cpp b/kicker/kicker/ui/hidebutton.cpp
index 58bde0457..77e1dc22c 100644
--- a/kicker/kicker/ui/hidebutton.cpp
+++ b/kicker/kicker/ui/hidebutton.cpp
@@ -51,22 +51,22 @@ void HideButton::drawButton(TQPainter *p)
{
if (m_arrow == Qt::LeftArrow)
{
- p->setPen(tqcolorGroup().mid());
+ p->setPen(colorGroup().mid());
p->drawLine(width()-1, 0, width()-1, height());
}
else if (m_arrow == Qt::RightArrow)
{
- p->setPen(tqcolorGroup().mid());
+ p->setPen(colorGroup().mid());
p->drawLine(0, 0, 0, height());
}
else if (m_arrow == Qt::UpArrow)
{
- p->setPen(tqcolorGroup().mid());
+ p->setPen(colorGroup().mid());
p->drawLine(0, height()-1, width(), height()-1);
}
else if (m_arrow == Qt::DownArrow)
{
- p->setPen(tqcolorGroup().mid());
+ p->setPen(colorGroup().mid());
p->drawLine(0, 0, width(), 0);
}
diff --git a/kicker/kicker/ui/itemview.cpp b/kicker/kicker/ui/itemview.cpp
index f9ab06006..dbe1ee29a 100644
--- a/kicker/kicker/ui/itemview.cpp
+++ b/kicker/kicker/ui/itemview.cpp
@@ -166,7 +166,7 @@ void KMenuItem::setup()
void KMenuItem::paintCell(TQPainter* p, const TQColorGroup & cg, int column, int width, int align)
{
ItemView *listview = static_cast<ItemView*>( listView() );
- int bottom = listView()->tqitemRect( this ).bottom();
+ int bottom = listView()->itemRect( this ).bottom();
int diff = bottom - listView()->viewport()->height();
KPixmap pm;
@@ -608,7 +608,7 @@ void ItemViewTip::maybeTip( const TQPoint &pos )
if ( item->toolTip().isNull() )
return;
- TQRect r = view->tqitemRect( item );
+ TQRect r = view->itemRect( item );
int headerPos = view->header()->sectionPos( 0 );
r.setLeft( headerPos );
r.setRight( headerPos + view->header()->sectionSize( 0 ) );
@@ -915,7 +915,7 @@ void ItemView::contentsMousePressEvent ( TQMouseEvent * e )
KMenuItemSeparator *si = dynamic_cast<KMenuItemSeparator*>( itemAt( vp ) );
if ( si )
{
- if ( si->hitsLink( vp - tqitemRect(si).topLeft() ) )
+ if ( si->hitsLink( vp - itemRect(si).topLeft() ) )
emit startURL( si->linkUrl() );
}
}
@@ -928,7 +928,7 @@ void ItemView::contentsMouseMoveEvent(TQMouseEvent *e)
bool link_cursor = false;
KMenuItemSeparator *si = dynamic_cast<KMenuItemSeparator*>( i );
if ( si )
- link_cursor = si->hitsLink( vp - tqitemRect(si).topLeft() );
+ link_cursor = si->hitsLink( vp - itemRect(si).topLeft() );
if (i && !i->isSelectable() && !link_cursor) {
unsetCursor();
@@ -965,7 +965,7 @@ void ItemView::resizeEvent ( TQResizeEvent * e )
{
KListView::resizeEvent( e );
// if ( m_lastOne )
-// int diff = tqitemRect( m_lastOne ).bottom() - viewport()->height();
+// int diff = itemRect( m_lastOne ).bottom() - viewport()->height();
}
void ItemView::viewportPaintEvent ( TQPaintEvent * pe )
@@ -1052,7 +1052,7 @@ TQDragObject * ItemView::dragObject()
else if(!kitem->path().isEmpty() && !kitem->path().startsWith("kicker:/") && !kitem->path().startsWith("kaddressbook:/")) {
TQString uri = kitem->path();
- if (uri.startsWith(locateLocal("data", TQString::tqfromLatin1("RecentDocuments/")))) {
+ if (uri.startsWith(locateLocal("data", TQString::fromLatin1("RecentDocuments/")))) {
KDesktopFile df(uri,true);
uri=df.readURL();
}
@@ -1103,7 +1103,7 @@ const char * KMenuItemDrag::format(int i) const
return 0;
}
-TQByteArray KMenuItemDrag::tqencodedData(const char* mimeType) const
+TQByteArray KMenuItemDrag::encodedData(const char* mimeType) const
{
if (TQString("application/kmenuitem") == mimeType)
return a;
@@ -1138,7 +1138,7 @@ bool ItemView::acceptDrag (TQDropEvent* event) const
bool KMenuItemDrag::decode(const TQMimeSource* e, KMenuItemInfo& item)
{
- TQByteArray a = e->tqencodedData("application/kmenuitem");
+ TQByteArray a = e->encodedData("application/kmenuitem");
if (a.isEmpty()) {
TQStringList l;
@@ -1211,7 +1211,7 @@ bool FavoritesItemView::acceptDrag (TQDropEvent* event) const
TQString uri = item.m_path;
- if (uri.startsWith(locateLocal("data", TQString::tqfromLatin1("RecentDocuments/")))) {
+ if (uri.startsWith(locateLocal("data", TQString::fromLatin1("RecentDocuments/")))) {
KDesktopFile df(uri,true);
uri=df.readURL();
}
diff --git a/kicker/kicker/ui/itemview.h b/kicker/kicker/ui/itemview.h
index 2a6b7e68b..c8b95ee42 100644
--- a/kicker/kicker/ui/itemview.h
+++ b/kicker/kicker/ui/itemview.h
@@ -248,7 +248,7 @@ class KMenuItemDrag : public TQDragObject
~KMenuItemDrag();
virtual const char * format(int i = 0) const;
- virtual TQByteArray tqencodedData(const char *) const;
+ virtual TQByteArray encodedData(const char *) const;
static bool canDecode(const TQMimeSource * e);
static bool decode(const TQMimeSource* e, KMenuItemInfo& item);
diff --git a/kicker/kicker/ui/k_mnu.cpp b/kicker/kicker/ui/k_mnu.cpp
index 6953143c9..d43e3b17a 100644
--- a/kicker/kicker/ui/k_mnu.cpp
+++ b/kicker/kicker/ui/k_mnu.cpp
@@ -211,7 +211,7 @@ void PanelKMenu::paletteChanged()
if (!loadSidePixmap())
{
sidePixmap = sideTilePixmap = TQPixmap();
- setMinimumSize( tqsizeHint() );
+ setMinimumSize( sizeHint() );
}
}
@@ -584,7 +584,7 @@ void PanelKMenu::showMenu()
TQRect PanelKMenu::sideImageRect()
{
- return TQStyle::tqvisualRect( TQRect( frameWidth(), frameWidth(), sidePixmap.width(),
+ return TQStyle::visualRect( TQRect( frameWidth(), frameWidth(), sidePixmap.width(),
height() - 2*frameWidth() ), this );
}
@@ -595,21 +595,21 @@ void PanelKMenu::resizeEvent(TQResizeEvent * e)
PanelServiceMenu::resizeEvent(e);
- setFrameRect( TQStyle::tqvisualRect( TQRect( sidePixmap.width(), 0,
+ setFrameRect( TQStyle::visualRect( TQRect( sidePixmap.width(), 0,
width() - sidePixmap.width(), height() ), this ) );
}
//Workaround Qt3.3.x sizing bug, by ensuring we're always wide enough.
void PanelKMenu::resize(int width, int height)
{
- width = kMax(width, tqmaximumSize().width());
+ width = kMax(width, maximumSize().width());
PanelServiceMenu::resize(width, height);
}
-TQSize PanelKMenu::tqsizeHint() const
+TQSize PanelKMenu::sizeHint() const
{
- TQSize s = PanelServiceMenu::tqsizeHint();
-// kdDebug(1210) << "PanelKMenu::tqsizeHint()" << endl;
+ TQSize s = PanelServiceMenu::sizeHint();
+// kdDebug(1210) << "PanelKMenu::sizeHint()" << endl;
// kdDebug(1210) << s.width() << ", " << s.height() << endl;
return s;
}
@@ -626,7 +626,7 @@ void PanelKMenu::paintEvent(TQPaintEvent * e)
tqstyle().tqdrawPrimitive( TQStyle::PE_PanelPopup, &p,
TQRect( 0, 0, width(), height() ),
- tqcolorGroup(), TQStyle::Style_Default,
+ colorGroup(), TQStyle::Style_Default,
TQStyleOption( frameWidth(), 0 ) );
TQRect r = sideImageRect();
diff --git a/kicker/kicker/ui/k_mnu.h b/kicker/kicker/ui/k_mnu.h
index f7ad2ee77..53a29d809 100644
--- a/kicker/kicker/ui/k_mnu.h
+++ b/kicker/kicker/ui/k_mnu.h
@@ -59,7 +59,7 @@ public:
int insertClientMenu(KickerClientMenu *p);
void removeClientMenu(int id);
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
virtual void setMinimumSize(const TQSize &);
virtual void setMaximumSize(const TQSize &);
virtual void setMinimumSize(int, int);
diff --git a/kicker/kicker/ui/k_mnu_stub.cpp b/kicker/kicker/ui/k_mnu_stub.cpp
index 16e755d48..b02d2bcbf 100644
--- a/kicker/kicker/ui/k_mnu_stub.cpp
+++ b/kicker/kicker/ui/k_mnu_stub.cpp
@@ -97,11 +97,11 @@ void KMenuStub::resize(int w, int h)
return m_w.panelkmenu->resize(w, h);
}
-TQSize KMenuStub::tqsizeHint() const
+TQSize KMenuStub::sizeHint() const
{
if(m_type == t_KMenu)
- return m_w.kmenu->tqsizeHint();
- return m_w.panelkmenu->tqsizeHint();
+ return m_w.kmenu->sizeHint();
+ return m_w.panelkmenu->sizeHint();
}
bool KMenuStub::highlightMenuItem( const TQString &menuId )
diff --git a/kicker/kicker/ui/k_mnu_stub.h b/kicker/kicker/ui/k_mnu_stub.h
index 17fe92b7c..362d132b2 100644
--- a/kicker/kicker/ui/k_mnu_stub.h
+++ b/kicker/kicker/ui/k_mnu_stub.h
@@ -53,7 +53,7 @@ public:
void popup(const TQPoint &pos, int indexAtPoint = -1);
void selectFirstItem();
void resize(int, int);
- TQSize tqsizeHint() const;
+ TQSize sizeHint() const;
bool highlightMenuItem( const TQString &menuId );
void clearRecentMenuItems();
void initialize();
diff --git a/kicker/kicker/ui/k_new_mnu.cpp b/kicker/kicker/ui/k_new_mnu.cpp
index e27f47d88..facc0975e 100644
--- a/kicker/kicker/ui/k_new_mnu.cpp
+++ b/kicker/kicker/ui/k_new_mnu.cpp
@@ -302,7 +302,7 @@ KMenu::KMenu()
m_searchInternet->setPixmap(0,icon);
setTabOrder(m_kcommand, m_searchResultsWidget);
- m_kerryInstalled = !KStandardDirs::findExe(TQString::tqfromLatin1("kerry")).isEmpty();
+ m_kerryInstalled = !KStandardDirs::findExe(TQString::fromLatin1("kerry")).isEmpty();
m_isShowing = false;
if (!m_kerryInstalled) {
@@ -421,7 +421,7 @@ void KMenu::setupUi()
{
m_stacker = new TQWidgetStack( this, "m_stacker" );
m_stacker->setGeometry( TQRect( 90, 260, 320, 220 ) );
- m_stacker->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)3, (TQSizePolicy::SizeType)3, 1, 1, m_stacker->sizePolicy().hasHeightForWidth() ) );
+ m_stacker->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)3, (TQSizePolicy::SizeType)3, 1, 1, m_stacker->sizePolicy().hasHeightForWidth() ) );
m_stacker->setPaletteBackgroundColor( TQColor( 255, 255, 255 ) );
// m_stacker->setFocusPolicy( TQ_StrongFocus );
m_stacker->setLineWidth( 0 );
@@ -522,7 +522,7 @@ bool KMenu::eventFilter ( TQObject * receiver, TQEvent* e)
m_sloppySourceClicked = true;
if (!m_sloppyTimer.isActive() || m_sloppySource != raiseRect) {
- int timeout= tqstyle().tqstyleHint(TQStyle::SH_PopupMenu_SubMenuPopupDelay);
+ int timeout= tqstyle().styleHint(TQStyle::SH_PopupMenu_SubMenuPopupDelay);
if (m_sloppySourceClicked)
timeout = 3000;
m_sloppyTimer.start(timeout);
@@ -1699,14 +1699,14 @@ void KMenu::setOrientation(MenuOrientation orientation)
TQWidget *footer = m_footer->mainWidget();
TQPixmap pix( 64, footer->height() );
TQPainter p( &pix );
- p.fillRect( 0, 0, 64, footer->height(), m_branding->tqcolorGroup().brush( TQColorGroup::Base ) );
+ p.fillRect( 0, 0, 64, footer->height(), m_branding->colorGroup().brush( TQColorGroup::Base ) );
p.fillRect( 0, m_orientation == BottomUp ? footer->height() - 2 : 0,
64, 3, KNewButton::self()->borderColor() );
p.end();
footer->setPaletteBackgroundPixmap( pix );
}
- resizeEvent(new TQResizeEvent(tqsizeHint(), tqsizeHint()));
+ resizeEvent(new TQResizeEvent(sizeHint(), sizeHint()));
}
void KMenu::showMenu()
@@ -1762,7 +1762,7 @@ void KMenu::paintEvent(TQPaintEvent * e)
const BackgroundMode bgmode = backgroundMode();
const TQColorGroup::ColorRole crole = TQPalette::backgroundRoleFromMode( bgmode );
- p.setBrush( tqcolorGroup().brush( crole ) );
+ p.setBrush( colorGroup().brush( crole ) );
p.drawRect( 0, 0, width(), height() );
int ypos = m_search->mainWidget()->geometry().bottom();
@@ -1923,7 +1923,7 @@ void KMenu::createNewProgramList()
m_seenPrograms = KickerSettings::firstSeenApps();
m_newInstalledPrograms.clear();
- m_tqcurrentDate = TQDate::currentDate().toString(Qt::ISODate);
+ m_currentDate = TQDate::currentDate().toString(Qt::ISODate);
bool initialize = (m_seenPrograms.count() == 0);
@@ -1978,7 +1978,7 @@ void KMenu::createNewProgramList(TQString relPath)
if (!found) {
m_seenProgramsChanged=true;
m_seenPrograms+=shortStorageId;
- m_seenPrograms+=m_tqcurrentDate;
+ m_seenPrograms+=m_currentDate;
if (m_newInstalledPrograms.find(s->storageId())==m_newInstalledPrograms.end())
m_newInstalledPrograms+=s->storageId();
}
@@ -2744,7 +2744,7 @@ void KMenu::slotContextMenuRequested( TQListViewItem * item, const TQPoint & pos
m_popupPath.path = kitem->path();
m_popupPath.icon = kitem->icon();
- if (m_popupPath.path.startsWith(locateLocal("data", TQString::tqfromLatin1("RecentDocuments/")))) {
+ if (m_popupPath.path.startsWith(locateLocal("data", TQString::fromLatin1("RecentDocuments/")))) {
KDesktopFile df(m_popupPath.path,true);
m_popupPath.path=df.readURL();
}
@@ -2936,7 +2936,7 @@ void KMenu::slotContextMenu(int selected)
case EditMenu:
accept();
proc = new KProcess(TQT_TQOBJECT(this));
- *proc << KStandardDirs::findExe(TQString::tqfromLatin1("kmenuedit"));
+ *proc << KStandardDirs::findExe(TQString::fromLatin1("kmenuedit"));
*proc << "/"+m_popupPath.menuPath.section('/',-200,-2) << m_popupPath.menuPath.section('/', -1);
proc->start();
break;
@@ -3074,24 +3074,24 @@ void KMenu::resizeEvent ( TQResizeEvent * e )
// put the search widget at the top of the menu and give it its desired
// height
m_search->mainWidget()->setGeometry( 0, ypos, width(),
- m_search->tqminimumSize().height() );
- left_height -= m_search->tqminimumSize().height();
- ypos += m_search->tqminimumSize().height();
+ m_search->minimumSize().height() );
+ left_height -= m_search->minimumSize().height();
+ ypos += m_search->minimumSize().height();
// place the footer widget at the bottom of the menu and give it its desired
// height
- m_footer->mainWidget()->setGeometry( 0, height() - m_footer->tqminimumSize().height(),
- width(), m_footer->tqminimumSize().height() );
- left_height -= m_footer->tqminimumSize().height();
+ m_footer->mainWidget()->setGeometry( 0, height() - m_footer->minimumSize().height(),
+ width(), m_footer->minimumSize().height() );
+ left_height -= m_footer->minimumSize().height();
// place the button box above the footer widget, horizontal placement
// has the width of the edge graphics subtracted
m_tabBar->setGeometry(button_box_left.width(),
- height() - m_footer->tqminimumSize().height() -
- m_tabBar->tqsizeHint().height(),
+ height() - m_footer->minimumSize().height() -
+ m_tabBar->sizeHint().height(),
width() - button_box_left.width(),
- m_tabBar->tqsizeHint().height() );
- left_height -= m_tabBar->tqsizeHint().height();
+ m_tabBar->sizeHint().height() );
+ left_height -= m_tabBar->sizeHint().height();
// place the main (stacker) widget below the search widget,
// in the remaining vertical space
@@ -3105,28 +3105,28 @@ void KMenu::resizeEvent ( TQResizeEvent * e )
// place the 'footer' widget at the top of the menu and give it
// its desired height
m_footer->mainWidget()->setGeometry( 0,
- ypos /*height() - m_footer->tqminimumSize().height()*/,
+ ypos /*height() - m_footer->minimumSize().height()*/,
width(),
- m_footer->tqminimumSize().height() );
- ypos += m_footer->tqminimumSize().height();
- left_height -= m_footer->tqminimumSize().height();
+ m_footer->minimumSize().height() );
+ ypos += m_footer->minimumSize().height();
+ left_height -= m_footer->minimumSize().height();
// place the button box next at the top of the menu.
// has the width of the edge graphics subtracted
m_tabBar->setGeometry(button_box_left.width(), ypos, width() - button_box_left.width(),
- m_tabBar->tqsizeHint().height());
+ m_tabBar->sizeHint().height());
- ypos += m_tabBar->tqsizeHint().height();
- left_height -= m_tabBar->tqsizeHint().height();
+ ypos += m_tabBar->sizeHint().height();
+ left_height -= m_tabBar->sizeHint().height();
// put the search widget above the footer widget
// height
m_search->mainWidget()->setGeometry( 0,
- height() - m_search->tqminimumSize().height(),
+ height() - m_search->minimumSize().height(),
width(),
- m_search->tqminimumSize().height()
+ m_search->minimumSize().height()
);
- left_height -= m_search->tqminimumSize().height();
+ left_height -= m_search->minimumSize().height();
// place the main (stacker) widget below the button box,
// in the remaining vertical space
@@ -3167,14 +3167,14 @@ void KMenu::mouseMoveEvent ( TQMouseEvent * e )
if ( hasMouseTracking() && m_isresizing ) {
m_stacker->setMinimumSize( TQSize(0, 0) );
m_stacker->setMaximumSize( TQSize(32000, 32000) );
- int newWidth = QMAX( e->x() - x(), tqminimumSizeHint().width() );
+ int newWidth = QMAX( e->x() - x(), minimumSizeHint().width() );
if ( m_orientation == BottomUp ) {
- int newHeight = QMAX( height() - e->y(), tqminimumSizeHint().height() + 10 );
+ int newHeight = QMAX( height() - e->y(), minimumSizeHint().height() + 10 );
int newY = y() + height() - newHeight;
setGeometry( x(), newY, newWidth, newHeight);
}
else {
- setGeometry( x(), y(), newWidth, QMAX( e->y(), tqminimumSizeHint().height() + 10 ));
+ setGeometry( x(), y(), newWidth, QMAX( e->y(), minimumSizeHint().height() + 10 ));
}
}
}
@@ -3331,7 +3331,7 @@ void KMenu::updateRecentlyUsedApps(KService::Ptr &service)
RecentlyLaunchedApps::the().m_bNeedToUpdate = true;
}
-TQSize KMenu::tqsizeHint() const
+TQSize KMenu::sizeHint() const
{
#warning FIXME
// this should be only for the inner area so layout changes do not break it
@@ -3339,28 +3339,28 @@ TQSize KMenu::tqsizeHint() const
const int height = kMin(KickerSettings::kMenuHeight(), TQApplication::desktop()->screen()->height()-50);
TQSize wanted(width, height);
- kdDebug() << "show " << tqminimumSizeHint() << " " << m_stacker->tqminimumSizeHint() << " "
- << m_searchFrame->tqminimumSizeHint() << " " << wanted << endl;
+ kdDebug() << "show " << minimumSizeHint() << " " << m_stacker->minimumSizeHint() << " "
+ << m_searchFrame->minimumSizeHint() << " " << wanted << endl;
bool isDefault = wanted.isNull();
- wanted = wanted.expandedTo(tqminimumSizeHint());
+ wanted = wanted.expandedTo(minimumSizeHint());
if ( isDefault )
- wanted.setHeight( wanted.height() + ( m_favoriteView->goodHeight() - m_stacker->tqminimumSizeHint().height() ) );
+ wanted.setHeight( wanted.height() + ( m_favoriteView->goodHeight() - m_stacker->minimumSizeHint().height() ) );
return wanted;
}
-TQSize KMenu::tqminimumSizeHint() const
+TQSize KMenu::minimumSizeHint() const
{
TQSize minsize;
- minsize.setWidth( minsize.width() + m_tabBar->tqsizeHint().width() );
+ minsize.setWidth( minsize.width() + m_tabBar->sizeHint().width() );
minsize.setWidth( QMAX( minsize.width(),
- m_search->tqminimumSize().width() ) );
+ m_search->minimumSize().width() ) );
minsize.setWidth( QMAX( minsize.width(),
- m_search->tqminimumSize().width() ) );
+ m_search->minimumSize().width() ) );
minsize.setHeight( minsize.height() +
- m_search->tqminimumSize().height() +
- m_footer->tqminimumSize().height() +
+ m_search->minimumSize().height() +
+ m_footer->minimumSize().height() +
180 ); // 180 is a very rough guess for 32 icon size
return minsize;
}
@@ -3558,7 +3558,7 @@ void KMenu::slotFavDropped(TQDropEvent * ev, TQListViewItem *after )
else
{
TQString uri = item.m_path;
- if (uri.startsWith(locateLocal("data", TQString::tqfromLatin1("RecentDocuments/")))) {
+ if (uri.startsWith(locateLocal("data", TQString::fromLatin1("RecentDocuments/")))) {
KDesktopFile df(uri,true);
uri=df.readURL();
}
diff --git a/kicker/kicker/ui/k_new_mnu.h b/kicker/kicker/ui/k_new_mnu.h
index 73549cfa0..ef45ef815 100644
--- a/kicker/kicker/ui/k_new_mnu.h
+++ b/kicker/kicker/ui/k_new_mnu.h
@@ -104,8 +104,8 @@ public:
enum MaskEffect { Plain, Dissolve };
- virtual TQSize tqsizeHint() const;
- virtual TQSize tqminimumSizeHint() const;
+ virtual TQSize sizeHint() const;
+ virtual TQSize minimumSizeHint() const;
void searchOver();
void initCategoryTitlesUpdate();
@@ -319,7 +319,7 @@ private:
TQStringList m_programsInMenu;
TQStringList m_newInstalledPrograms, m_seenPrograms;
bool m_seenProgramsChanged;
- TQString m_tqcurrentDate;
+ TQString m_currentDate;
MenuOrientation m_orientation;
bool m_toolTipsEnabled;
diff --git a/kicker/kicker/ui/kickoff_bar.cpp b/kicker/kicker/ui/kickoff_bar.cpp
index 6a41a719b..bf90263e0 100644
--- a/kicker/kicker/ui/kickoff_bar.cpp
+++ b/kicker/kicker/ui/kickoff_bar.cpp
@@ -58,8 +58,8 @@ void KickoffTabBar::paint(TQPainter* p, TQTab* t, bool selected) const
//selection flags
if(t->rect().contains(mapFromGlobal(TQCursor::pos())))
flags |= TQStyle::Style_MouseOver;
- tqstyle().tqdrawControl( TQStyle::CE_TabBarTab, p, this, t->rect(),
- tqcolorGroup(), flags, TQStyleOption(t) );
+ tqstyle().drawControl( TQStyle::CE_TabBarTab, p, this, t->rect(),
+ colorGroup(), flags, TQStyleOption(t) );
paintLabel( p, t->rect(), t, t->identifier() == keyboardFocusTab() );
}
@@ -70,7 +70,7 @@ void KickoffTabBar::paintLabel(TQPainter* p, const TQRect& br, TQTab* t, bool ha
TQRect r = br;
bool selected = m_tabsActivated && (currentTab() == t->identifier());
- int vframe = tqstyle().tqpixelMetric( TQStyle::PM_TabBarTabVSpace, this );
+ int vframe = tqstyle().pixelMetric( TQStyle::PM_TabBarTabVSpace, this );
p->setFont( font() );
TQFontMetrics fm = p->fontMetrics();
@@ -116,14 +116,14 @@ void KickoffTabBar::paintLabel(TQPainter* p, const TQRect& br, TQTab* t, bool ha
// flags |= TQStyle::Style_Sunken;
if(t->rect().contains(mapFromGlobal(TQCursor::pos())))
flags |= TQStyle::Style_MouseOver;
- tqstyle().tqdrawControl( TQStyle::CE_TabBarLabel, p, this, rt,
- t->isEnabled() ? tqcolorGroup(): tqpalette().disabled(),
+ tqstyle().drawControl( TQStyle::CE_TabBarLabel, p, this, rt,
+ t->isEnabled() ? colorGroup(): tqpalette().disabled(),
flags, TQStyleOption(t) );
}
-TQSize KickoffTabBar::tqsizeHint() const
+TQSize KickoffTabBar::sizeHint() const
{
- TQSize s = TQTabBar::tqsizeHint();
+ TQSize s = TQTabBar::sizeHint();
return s;
}
@@ -135,9 +135,9 @@ void KickoffTabBar::layoutTabs()
TQFontMetrics fm = fontMetrics();
int fh = ((KickerSettings::kickoffTabBarFormat() != KickerSettings::IconOnly) ? fm.height() : 0) + 4;
- int hframe = tqstyle().tqpixelMetric( TQStyle::PM_TabBarTabHSpace, this );
- int vframe = tqstyle().tqpixelMetric( TQStyle::PM_TabBarTabVSpace, this );
- int overlap = tqstyle().tqpixelMetric( TQStyle::PM_TabBarTabOverlap, this );
+ int hframe = tqstyle().pixelMetric( TQStyle::PM_TabBarTabHSpace, this );
+ int vframe = tqstyle().pixelMetric( TQStyle::PM_TabBarTabVSpace, this );
+ int overlap = tqstyle().pixelMetric( TQStyle::PM_TabBarTabOverlap, this );
TQSize s;
for (int t = 0; t < count(); ++t)
diff --git a/kicker/kicker/ui/kickoff_bar.h b/kicker/kicker/ui/kickoff_bar.h
index 55f94c3dd..2330ffe39 100644
--- a/kicker/kicker/ui/kickoff_bar.h
+++ b/kicker/kicker/ui/kickoff_bar.h
@@ -32,7 +32,7 @@ public:
KickoffTabBar(TQWidget* parent, const char* name);
void deactivateTabs(bool b);
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
protected:
virtual void paint(TQPainter*, TQTab*, bool) const;
diff --git a/kicker/kicker/ui/kmenuitembase.ui b/kicker/kicker/ui/kmenuitembase.ui
index 0b49763a1..113fc905b 100644
--- a/kicker/kicker/ui/kmenuitembase.ui
+++ b/kicker/kicker/ui/kmenuitembase.ui
@@ -20,13 +20,13 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>0</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>32767</width>
<height>80</height>
@@ -120,7 +120,7 @@
<property name="name">
<cstring>itemPixmap</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>64</width>
<height>64</height>
diff --git a/kicker/kicker/ui/nonKDEButtonSettings.ui b/kicker/kicker/ui/nonKDEButtonSettings.ui
index a3f04e6a8..187dd7cb5 100644
--- a/kicker/kicker/ui/nonKDEButtonSettings.ui
+++ b/kicker/kicker/ui/nonKDEButtonSettings.ui
@@ -121,7 +121,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -140,13 +140,13 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>58</width>
<height>58</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>58</width>
<height>58</height>
@@ -199,7 +199,7 @@
<property name="sizeType">
<enum>Minimum</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>8</height>
diff --git a/kicker/kicker/ui/popupmenutitle.h b/kicker/kicker/ui/popupmenutitle.h
index c9e545417..1e15179f7 100644
--- a/kicker/kicker/ui/popupmenutitle.h
+++ b/kicker/kicker/ui/popupmenutitle.h
@@ -69,11 +69,11 @@ public:
m_font.setBold(true);
}
- TQSize tqsizeHint()
+ TQSize sizeHint()
{
TQSize size = TQFontMetrics(m_font).size(AlignHCenter, m_desktopName);
size.setHeight(size.height() +
- (kapp->tqstyle().tqpixelMetric(TQStyle::PM_DefaultFrameWidth) * 2 + 1));
+ (kapp->tqstyle().pixelMetric(TQStyle::PM_DefaultFrameWidth) * 2 + 1));
return size;
}
diff --git a/kicker/kicker/ui/service_mnu.cpp b/kicker/kicker/ui/service_mnu.cpp
index ee0414644..982586c2f 100644
--- a/kicker/kicker/ui/service_mnu.cpp
+++ b/kicker/kicker/ui/service_mnu.cpp
@@ -695,7 +695,7 @@ void PanelServiceMenu::slotContextMenu(int selected)
case EditItem:
proc = new KProcess(TQT_TQOBJECT(this));
- *proc << KStandardDirs::findExe(TQString::tqfromLatin1("kmenuedit"));
+ *proc << KStandardDirs::findExe(TQString::fromLatin1("kmenuedit"));
*proc << "/"+relPath_ << static_cast<KService *>(contextKSycocaEntry_)->menuId();
proc->start();
break;
@@ -739,7 +739,7 @@ void PanelServiceMenu::slotContextMenu(int selected)
case EditMenu:
proc = new KProcess(TQT_TQOBJECT(this));
- *proc << KStandardDirs::findExe(TQString::tqfromLatin1("kmenuedit"));
+ *proc << KStandardDirs::findExe(TQString::fromLatin1("kmenuedit"));
*proc << "/"+static_cast<KServiceGroup *>(contextKSycocaEntry_)->relPath();
proc->start();
break;
diff --git a/kicker/kicker/core/container_extension.cpp b/kicker/kicker/core/container_extension.cpp
index 51a9904d7..c56672949 100644
--- a/kicker/kicker/core/container_extension.cpp
+++ b/kicker/kicker/core/container_extension.cpp
@@ -224,7 +224,7 @@ ExtensionContainer::~ExtensionContainer()
{
}
-TQSize ExtensionContainer::tqsizeHint(KPanelExtension::Position p, const TQSize &maxSize) const
+TQSize ExtensionContainer::sizeHint(KPanelExtension::Position p, const TQSize &maxSize) const
{
int width = 0;
int height = 0;
@@ -284,7 +284,7 @@ TQSize ExtensionContainer::tqsizeHint(KPanelExtension::Position p, const TQSize
if (m_extension)
{
- size = m_extension->tqsizeHint(p, maxSize - size) + size;
+ size = m_extension->sizeHint(p, maxSize - size) + size;
}
return size.boundedTo(maxSize);
@@ -510,7 +510,7 @@ void ExtensionContainer::moveMe()
// on other parameters this can lead to Bad Things(tm)
//
// we need to find a way to do this that doesn't result in
// tqsizeHint's getting called on the extension =/
//
// or else we need to change the semantics for applets so that
// they don't get their "you're changing position" signals through
@@ -578,7 +578,7 @@ void ExtensionContainer::enableMouseOverEffects()
KickerTip::enableTipping(true);
TQPoint globalPos = TQCursor::pos();
TQPoint localPos = mapFromGlobal(globalPos);
- TQWidget* child = tqchildAt(localPos);
+ TQWidget* child = childAt(localPos);
if (child)
{
@@ -1408,11 +1408,11 @@ void ExtensionContainer::paintEvent(TQPaintEvent *e)
// KPanelExtension::Left/Right don't seem to draw the separators at all!
if (position() == KPanelExtension::Left) {
rect = TQRect(width()-2,0,PANEL_RESIZE_HANDLE_WIDTH,height());
- tqstyle().tqdrawPrimitive( TQStyle::PE_Separator, &p, rect, tqcolorGroup(), TQStyle::Style_Horizontal );
+ tqstyle().tqdrawPrimitive( TQStyle::PE_Separator, &p, rect, colorGroup(), TQStyle::Style_Horizontal );
}
else if (position() == KPanelExtension::Right) {
rect = TQRect(0,0,PANEL_RESIZE_HANDLE_WIDTH,height());
- tqstyle().tqdrawPrimitive( TQStyle::PE_Separator, &p, rect, tqcolorGroup(), TQStyle::Style_Horizontal );
+ tqstyle().tqdrawPrimitive( TQStyle::PE_Separator, &p, rect, colorGroup(), TQStyle::Style_Horizontal );
}
else if (position() == KPanelExtension::Top) {
// Nastiness to both vertically flip the PE_Separator
@@ -1420,14 +1420,14 @@ void ExtensionContainer::paintEvent(TQPaintEvent *e)
TQPixmap inv_pm(width(),PANEL_RESIZE_HANDLE_WIDTH);
TQPainter myp(TQT_TQPAINTDEVICE(&inv_pm));
rect = TQRect(0,0,width(),PANEL_RESIZE_HANDLE_WIDTH);
- TQColorGroup darkcg = tqcolorGroup();
- darkcg.setColor(TQColorGroup::Light, tqcolorGroup().dark());
+ TQColorGroup darkcg = colorGroup();
+ darkcg.setColor(TQColorGroup::Light, colorGroup().dark());
tqstyle().tqdrawPrimitive( TQStyle::PE_Separator, &myp, rect, darkcg, TQStyle::Style_Default );
p.drawPixmap(0,height()-2,inv_pm);
}
else {
rect = TQRect(0,0,width(),PANEL_RESIZE_HANDLE_WIDTH);
- tqstyle().tqdrawPrimitive( TQStyle::PE_Separator, &p, rect, tqcolorGroup(), TQStyle::Style_Default );
+ tqstyle().tqdrawPrimitive( TQStyle::PE_Separator, &p, rect, colorGroup(), TQStyle::Style_Default );
}
}
}
@@ -1444,7 +1444,7 @@ void ExtensionContainer::alignmentChange(KPanelExtension::Alignment a)
return;
}
- m_extension->tqsetAlignment(a);
+ m_extension->setAlignment(a);
}
void ExtensionContainer::setSize(KPanelExtension::Size size, int custom)
@@ -1551,7 +1551,7 @@ void ExtensionContainer::arrange(KPanelExtension::Position p,
if (a != m_settings.alignment())
{
m_settings.setAlignment(a);
- tqsetAlignment(a);
+ setAlignment(a);
}
if (XineramaScreen != xineramaScreen())
@@ -1777,7 +1777,7 @@ TQSize ExtensionContainer::initialSize(KPanelExtension::Position p, TQRect workA
", " << workArea.topLeft().y() << ") to (" << workArea.bottomRight().x() <<
", " << workArea.bottomRight().y() << ")" << endl;*/
- TQSize hint = tqsizeHint(p, workArea.size()).boundedTo(workArea.size());
+ TQSize hint = sizeHint(p, workArea.size()).boundedTo(workArea.size());
int width = 0;
int height = 0;
@@ -510,7 +510,7 @@ void ExtensionContainer::moveMe()
//
// we need to find a way to do this that doesn't result in
- // tqsizeHint's getting called on the extension =/
+ // sizeHint's getting called on the extension =/
//
// or else we need to change the semantics for applets so that
diff --git a/kicker/kicker/core/menumanager.cpp b/kicker/kicker/core/menumanager.cpp
index e6b7e3d60..af24e50da 100644
--- a/kicker/kicker/core/menumanager.cpp
+++ b/kicker/kicker/core/menumanager.cpp
@@ -156,8 +156,8 @@ void MenuManager::kmenuAccelActivated()
r = desktop->geometry();
else
r = desktop->screenGeometry(desktop->screenNumber(TQCursor::pos()));
- // kMenu->rect() is not valid before showing, use tqsizeHint()
- p = r.center() - TQRect( TQPoint( 0, 0 ), m_kmenu->tqsizeHint()).center();
+ // kMenu->rect() is not valid before showing, use sizeHint()
+ p = r.center() - TQRect( TQPoint( 0, 0 ), m_kmenu->sizeHint()).center();
m_kmenu->popup(p);
// when the cursor is in the area where the menu pops up,
@@ -170,8 +170,8 @@ void MenuManager::kmenuAccelActivated()
{
// We need the kmenu's size to place it at the right position.
// We cannot rely on the popup menu's current size(), if it wasn't
- // shown before, so we resize it here according to its tqsizeHint().
- const TQSize size = m_kmenu->tqsizeHint();
+ // shown before, so we resize it here according to its sizeHint().
+ const TQSize size = m_kmenu->sizeHint();
m_kmenu->resize(size.width(),size.height());
PanelPopupButton* button = findKButtonFor(m_kmenu->widget());